package cn.com.ctop.bytedance.service.impl;

import cn.com.ctop.bytedance.mapper.KuaiShouYiCheReportMapper;
import cn.com.ctop.bytedance.service.IKuaiShouYiCheReportService;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.util.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

@Slf4j
@Service
public class KuaiShouYiCheReportServiceImpl implements IKuaiShouYiCheReportService {
    @Autowired
    private KuaiShouYiCheReportMapper kuaiShouYiCheReportMapper;

    @Override
    public JSONObject getHourReport(JSONObject requestJson) {
        log.info("易车时报数据统计开始：requestJson:{}", requestJson);
        Long projectId = requestJson.getLong("projectId");
        BigDecimal disCount = requestJson.getBigDecimal("disCount");
        String statDate = DateUtils.getNowDate("yyyy-MM-dd");

        JSONObject returnJson = new JSONObject();
        Integer maxHour = kuaiShouYiCheReportMapper.getMaxHourByProjectIdAndStatDate(statDate, projectId);
        if (maxHour != null) {
            Map<String, Object> requestMap = new HashMap<>();
            requestMap.put("projectId", projectId);
            requestMap.put("disCount", disCount);
            requestMap.put("statDate", statDate);
            requestMap.put("statHour", maxHour);


            String yesterday = DateUtils.getAnotherDay("yyyy-MM-dd", statDate, -1);
            String weekAgoDay = DateUtils.getAnotherDay("yyyy-MM-dd", statDate, -6);

            // 安卓
            requestMap.put("systemType", "android");
            // 账号
            List<JSONObject> androidReportArr = kuaiShouYiCheReportMapper.selectReportByMap(requestMap);

            // 今日
            requestMap.put("statDate", statDate);
            requestMap.put("dateDesc", statDate + "整体数据");
            JSONObject nowJson = kuaiShouYiCheReportMapper.selectSumReportByMap(requestMap);
            androidReportArr.add(nowJson);

            // 昨日
            requestMap.put("statDate", yesterday);
            requestMap.put("dateDesc", "昨日整体数据");
            JSONObject yesterdayJson = kuaiShouYiCheReportMapper.selectSumReportByMap(requestMap);
            androidReportArr.add(yesterdayJson);
            // 七日
            requestMap.put("statDate", weekAgoDay);
            requestMap.put("dateDesc", "上周同期整体数据");

            JSONObject weekAgoJson = kuaiShouYiCheReportMapper.selectSumReportByMap(requestMap);
            androidReportArr.add(weekAgoJson);


            // ios
            requestMap.put("systemType", "IOS");
            // 账号
            List<JSONObject> iosReportArr = kuaiShouYiCheReportMapper.selectReportByMap(requestMap);

            // 今日
            requestMap.put("statDate", statDate);
            requestMap.put("dateDesc", statDate + "整体数据");
            JSONObject iosNowJson = kuaiShouYiCheReportMapper.selectSumReportByMap(requestMap);
            iosReportArr.add(iosNowJson);


            // 昨日
            requestMap.put("statDate", yesterday);
            requestMap.put("dateDesc", "昨日整体数据");
            JSONObject iosYesterdayJson = kuaiShouYiCheReportMapper.selectSumReportByMap(requestMap);
            iosReportArr.add(iosYesterdayJson);
            // 七日
            requestMap.put("statDate", weekAgoDay);
            requestMap.put("dateDesc", "上周同期整体数据");
            JSONObject iosWeekAgoJson = kuaiShouYiCheReportMapper.selectSumReportByMap(requestMap);
            iosReportArr.add(iosWeekAgoJson);

            returnJson.put("android", androidReportArr);
            returnJson.put("ios", iosReportArr);
        }

        return returnJson;
    }
}
